@@ -345,8 +345,8 @@ public:
 	}
 };
 
-typedef arrayref<const uint8_t *> bytearray_t;
-typedef arrayref<const char *> stringarray_t;
+typedef arrayref<bytes> bytearray_t;
+typedef arrayref<chars> stringarray_t;
 
 } // namespace
 
