@@ -253,238 +253,6 @@ public:
     }
 };
 
-/**
- * Manage temporary object stored on the heap.  This is used to create a
- * object on the heap who's scope is controlled by the scope of a member
- * function call.  Sometimes we have data types and structures which cannot
- * themselves appear as auto variables.  We may also have a limited stack
- * frame size in a thread context, and yet have a dynamic object that we
- * only want to exist during the life of the method call.  Using temporary
- * allows any type to be created from the heap but have a lifespan of a
- * method's stack frame.
- * @author David Sugar <dyfet@gnutelephony.org>
- */
-template <typename T>
-class temporary
-{
-private:
-    inline temporary(const temporary<T>&) {};
-
-protected:
-    T *array;
-    size_t used;
-
-public:
-    /**
-     * Construct a temporary object, create our stack frame reference.
-     */
-    inline temporary(size_t size = 1) {
-        array = new T[size];
-        used = size;
-    }    
-
-    inline temporary(size_t size, const T initial) {
-        array = new T[size];
-        used = size;
-        for(size_t p = 0; p < size; ++p)
-            array[p] = initial;
-    }
-
-    inline explicit temporary(const T initial) {
-        array = new T[1];
-        used = 1;
-        array[0] = initial;
-    }
-
-    inline ~temporary() {
-        if(array) {
-            delete[] array;
-            array = NULL;
-        }
-    }
-
-    inline operator T&() const {
-        return array[0];
-    }        
-
-    /**
-     * Access heap object through our temporary directly.
-     * @return reference to heap resident object.
-     */
-    inline T& operator*() const {
-        return array[0];
-    }
-
-    /**
-     * Access members of our heap object through our temporary.
-     * @return member reference of heap object.
-     */
-    inline T* operator->() const {
-        return &array[0];
-    }
-
-    inline operator bool() const {
-        return array != NULL;
-    }
-
-    inline bool operator!() const {
-        return array == NULL;
-    }
-
-    inline temporary& operator=(const T initial) {
-        array[0] = initial;
-        return *this;
-    }
-
-    inline void release() {
-        if(array) {
-            delete[] array;
-            array = NULL;
-        }
-    }
-
-    inline T& operator[](size_t index) const {
-        crit(index < used, "array out of bound");
-        return array[index];
-    }
-
-    inline T* operator()(size_t index) const {
-        crit(index < used, "array out of bound");
-        return &array[index];
-    }
-
-    inline void operator()(size_t index, const T value) {
-        crit(index < used, "array out of bound");
-        array[index] = value;
-    }
-
-    inline T& value(size_t index) const {
-        crit(index < used, "array out of bound");
-        return array[index];
-    }
-
-    inline void value(size_t index, const T value) {
-        crit(index < used, "array out of bound");
-        array[index] = value;
-    }
-};
-
-template<>
-class temporary<char *>
-{
-private:
-    inline temporary(const temporary<char *>&) {};
-
-protected:
-    char *object;
-    size_t used;
-
-public:
-    /**
-     * Construct a temporary object, create our stack frame reference.
-     */
-    inline temporary(size_t size) {
-        object = (char *)::malloc(size);
-        used = size;
-    }
-
-    inline operator char *() const {
-        return object;
-    }
-
-    inline size_t size() const {
-        return used;
-    }
-
-    /**
-     * Access heap object through our temporary directly.
-     * @return reference to heap resident object.
-     */
-    inline char *operator*() const {
-        return object;
-    }
-
-    inline operator bool() const {
-        return object != NULL;
-    }
-
-    inline bool operator!() const {
-        return object == NULL;
-    }
-
-    inline void release() {
-        if(object) {
-            ::free(object);
-            object = NULL;
-        }
-    }
-
-    inline ~temporary() {
-        if(object) {
-            ::free(object);
-            object = NULL;
-        }
-    }
-};
-
-template<>
-class temporary<uint8_t *>
-{
-private:
-    inline temporary(const temporary<uint8_t *>&) {};
-
-protected:
-    uint8_t *object;
-    size_t used;
-
-public:
-    /**
-     * Construct a temporary object, create our stack frame reference.
-     */
-    inline temporary(size_t size) {
-        object = (uint8_t *)::malloc(size);
-        used = size;
-    }
-
-    inline operator uint8_t *() const {
-        return object;
-    }
-
-    inline size_t size() const {
-        return used;
-    }
-
-    /**
-     * Access heap object through our temporary directly.
-     * @return reference to heap resident object.
-     */
-    inline uint8_t *operator*() const {
-        return object;
-    }
-
-    inline operator bool() const {
-        return object != NULL;
-    }
-
-    inline bool operator!() const {
-        return object == NULL;
-    }
-
-    inline void release() {
-        if(object) {
-            ::free(object);
-            object = NULL;
-        }
-    }
-
-    inline ~temporary() {
-        if(object) {
-            ::free(object);
-            object = NULL;
-        }
-    }
-};
-
 /**
  * Save and restore global objects in function call stack frames.
  * @author David Sugar <dyfet@gnutelephony.org>
@@ -518,7 +286,7 @@ public:
  * @param object we are testing.
  * @return true if object valid.
  */
-template<class T>
+template<typename T>
 inline bool is(T& object) {
     return object.operator bool();
 }
