@@ -133,6 +133,8 @@ public:
     strtype_t type(void);
 
     size_t size(void);
+
+    size_t len(void);
 };
 
 template <>
@@ -187,6 +189,20 @@ public:
     size_t size(void);
 };
 
+template<>
+inline size_t mapkeypath<secure_chars>(typeref<secure_chars>& object)
+{
+	size_t path = 1;
+	return MapRef::index(path, (const uint8_t *)(*object), object.len());
+}
+
+template<>
+inline size_t mapkeypath<secure_keybytes>(typeref<secure_keybytes>& object)
+{
+	size_t path = object.size();
+	return MapRef::index(path, *object, object.size() / 8);
+}
+
 /**
  * Common secure socket support.  This offers common routines needed for
  * secure/ssl socket support code.
@@ -200,17 +216,21 @@ public:
      */
     typedef enum {OK=0, INVALID, MISSING_CERTIFICATE, MISSING_PRIVATEKEY, INVALID_CERTIFICATE, INVALID_AUTHORITY, INVALID_PEERNAME, INVALID_CIPHER} error_t;
 
-    typedef typeref<secure_chars> string;
+    typedef secure_chars chars;
 
-    typedef arrayref<secure_chars> strarray;
+    typedef secure_keybytes bytes;
 
-    typedef queueref<secure_chars> strqueue;
+    typedef typeref<secure::chars> string;
 
-    typedef typeref<secure_keybytes> keybytes;
+    typedef arrayref<secure::chars> strarray;
+
+    typedef queueref<secure::chars> strqueue;
+
+    typedef typeref<secure::bytes> keybytes;
     
-    typedef typeref<secure_keybytes> keyarray;
+    typedef typeref<secure::bytes> keyarray;
 
-    typedef typeref<secure_keybytes> keyqueue;
+    typedef typeref<secure::bytes> keyqueue;
 
 protected:
     /**
