@@ -63,6 +63,7 @@ class __EXPORT TypeRef
 protected:
 	friend class ArrayRef;
 	friend class SharedRef;
+	friend class MapRef;
 
     /**
 	 * Heap base-class container for typeref objects.  This uses atomic
@@ -376,6 +377,8 @@ public:
 		return operator*();
 	}
 
+	size_t len() const;
+
 	bool operator==(const typeref& ptr) const;
 
 	bool operator==(const char *obj) const;
@@ -464,6 +467,8 @@ public:
 
 	typeref(uint8_t *str, size_t size);
 
+	typeref(bool mode, size_t bits);
+
 	inline explicit typeref(Counted *object) : TypeRef(object) {};
 
 	const uint8_t *operator*() const;
@@ -492,6 +497,12 @@ public:
 
 	void set(const uint8_t *str, size_t size);
 
+	size_t set(bool bit, size_t offset, size_t bits = 1);
+
+	bool get(size_t offset);
+
+	size_t count(size_t offset, size_t bits = 1);	
+
 	void assign(value *bytes);
 
 	static value *create(size_t size);
@@ -499,12 +510,16 @@ public:
 	static void destroy(value *bytes);
 };
 
-typedef typeref<const char*>::value *charvalues_t;
-typedef	typeref<const uint8_t *>::value	*bytevalues_t;
-typedef	typeref<const char*> stringref_t;
-typedef typeref<const char*> stringref;
-typedef typeref<const uint8_t *> byteref_t;
-typedef typeref<const uint8_t *> byteref;
+typedef	const char *chars;
+typedef	const uint8_t *bytes;
+typedef const uint8_t *bools;
+typedef typeref<chars>::value *charvalues_t;
+typedef	typeref<bytes>::value *bytevalues_t;
+typedef	typeref<chars> stringref_t;
+typedef typeref<chars> stringref;
+typedef typeref<bytes> byteref_t;
+typedef typeref<bytes> byteref;
+typedef typeref<bools> boolref_t;
 
 template<typename T>
 inline typeref<T> typeref_cast(T x) {
