@@ -162,11 +162,31 @@ extern "C" int main()
     assert(sv == 44);
     queueofints >> sv;
     assert(sv == 55);
+    assert(mapkeypath(sv) == 8779);
 
     // flush without delay...
     sv = queueofints.pull(0);
     assert(!sv.is());
     assert(sv.copies() == 0);
 
+    mapref<int,chars> map;
+    map(3, "hello");
+    stringref_t sr = map(3);
+    assert(eq(*sr, "hello"));
+    sr = map(2);
+    assert(*sr == nullptr);
+    typeref<int> ki(3);
+    sr = "goodbye";
+    map(ki, sr);
+    sr = map(3);
+    assert(eq(*sr, "goodbye"));
+    map(7, "test");
+    assert(map.count() == 2);
+
+    map.remove(7);
+    map(9, "9");
+    assert(map.used() == 2);
+    sr = map(7);
+    assert(*sr == nullptr);
     return 0;
 }
